==> openshift-model-miscellaneous-5.12.4-sources.jar: io/fabric8/openshift/api/model/miscellaneous/metal3/v1alpha1/HardwareDetailsBuilder.java <==
package io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class HardwareDetailsBuilder extends io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.HardwareDetailsFluentImpl<io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.HardwareDetailsBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.HardwareDetails,io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.HardwareDetailsBuilder>{
  public HardwareDetailsBuilder() {
    this(false);
  }
  public HardwareDetailsBuilder(java.lang.Boolean validationEnabled) {
    this(new HardwareDetails(), validationEnabled);
  }
  public HardwareDetailsBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.HardwareDetailsFluent<?> fluent) {
    this(fluent, false);
  }
  public HardwareDetailsBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.HardwareDetailsFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new HardwareDetails(), validationEnabled);
  }
  public HardwareDetailsBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.HardwareDetailsFluent<?> fluent,io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.HardwareDetails instance) {
    this(fluent, instance, false);
  }
  public HardwareDetailsBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.HardwareDetailsFluent<?> fluent,io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.HardwareDetails instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withCpu(instance.getCpu()); 
    fluent.withFirmware(instance.getFirmware()); 
    fluent.withHostname(instance.getHostname()); 
    fluent.withNics(instance.getNics()); 
    fluent.withRamMebibytes(instance.getRamMebibytes()); 
    fluent.withStorage(instance.getStorage()); 
    fluent.withSystemVendor(instance.getSystemVendor()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public HardwareDetailsBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.HardwareDetails instance) {
    this(instance,false);
  }
  public HardwareDetailsBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.HardwareDetails instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withCpu(instance.getCpu()); 
    this.withFirmware(instance.getFirmware()); 
    this.withHostname(instance.getHostname()); 
    this.withNics(instance.getNics()); 
    this.withRamMebibytes(instance.getRamMebibytes()); 
    this.withStorage(instance.getStorage()); 
    this.withSystemVendor(instance.getSystemVendor()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.HardwareDetailsFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.HardwareDetails build() {
    HardwareDetails buildable = new HardwareDetails(fluent.getCpu(),fluent.getFirmware(),fluent.getHostname(),fluent.getNics(),fluent.getRamMebibytes(),fluent.getStorage(),fluent.getSystemVendor());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HardwareDetailsBuilder that = (HardwareDetailsBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-miscellaneous-6.6.2-sources.jar: io/fabric8/openshift/api/model/miscellaneous/metal3/v1alpha1/HardwareDetailsBuilder.java <==
package io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class HardwareDetailsBuilder extends HardwareDetailsFluentImpl<HardwareDetailsBuilder> implements VisitableBuilder<HardwareDetails,HardwareDetailsBuilder>{
  public HardwareDetailsBuilder() {
    this(false);
  }
  public HardwareDetailsBuilder(Boolean validationEnabled) {
    this(new HardwareDetails(), validationEnabled);
  }
  public HardwareDetailsBuilder(HardwareDetailsFluent<?> fluent) {
    this(fluent, false);
  }
  public HardwareDetailsBuilder(HardwareDetailsFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new HardwareDetails(), validationEnabled);
  }
  public HardwareDetailsBuilder(HardwareDetailsFluent<?> fluent,HardwareDetails instance) {
    this(fluent, instance, false);
  }
  public HardwareDetailsBuilder(HardwareDetailsFluent<?> fluent,HardwareDetails instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withCpu(instance.getCpu()); 
    fluent.withFirmware(instance.getFirmware()); 
    fluent.withHostname(instance.getHostname()); 
    fluent.withNics(instance.getNics()); 
    fluent.withRamMebibytes(instance.getRamMebibytes()); 
    fluent.withStorage(instance.getStorage()); 
    fluent.withSystemVendor(instance.getSystemVendor()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public HardwareDetailsBuilder(HardwareDetails instance) {
    this(instance,false);
  }
  public HardwareDetailsBuilder(HardwareDetails instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withCpu(instance.getCpu()); 
    this.withFirmware(instance.getFirmware()); 
    this.withHostname(instance.getHostname()); 
    this.withNics(instance.getNics()); 
    this.withRamMebibytes(instance.getRamMebibytes()); 
    this.withStorage(instance.getStorage()); 
    this.withSystemVendor(instance.getSystemVendor()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  HardwareDetailsFluent<?> fluent;
  Boolean validationEnabled;
  public HardwareDetails build() {
    HardwareDetails buildable = new HardwareDetails(fluent.getCpu(),fluent.getFirmware(),fluent.getHostname(),fluent.getNics(),fluent.getRamMebibytes(),fluent.getStorage(),fluent.getSystemVendor());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
